@@ -111,8 +111,8 @@ class Command(object):
             inparse.prompt = ["First Buffer", "Last Buffer", "First Point", "Last Point"]
             inparse.inputbounds = [[1, lastbuffer], [1, lastbuffer],
                                    [1, min_idx],
-                                   [0, max_idx]]
-            inparse.defaultinput = ['1', str(lastbuffer), min_idx, max_idx]
+                                   [1, max_idx]]
+            inparse.defaultinput = ['1', str(lastbuffer), str(min_idx), str(max_idx)]
         if not inparse(args):
             return "Invalid input!"
         else:
@@ -899,6 +899,64 @@ class Command(object):
                 buffer.data.y.set(buffer.data.y.get() * const)
         return '\nData Successfully Multiplied!'
 
+    def do_mod(self, *args):
+        """\nCommand: MODel data with current parameters\n
+        Description:
+        \tModels defined function with defined parameters
+
+        Example Usage:
+        \tmod 1 2         (Models function for buffers 1 through 2)
+        \tmod -all        (Models function for all buffers)
+
+        Default Input: N/A
+
+        Default Options: N/A
+
+        \t-all     (Models function for all buffers)
+
+        Notes:
+        \tN/A
+        """
+        inparse = inputprocessing.InputParser()
+        lastbuffer = data.matrix.length()
+        firstbuffer = 1
+
+        if '-all' not in args and 'all' not in args:
+            inparse.prompt = ["First Buffer", "Last Buffer"]
+            inparse.inputbounds = [[firstbuffer, lastbuffer], [firstbuffer, lastbuffer]]
+            inparse.defaultinput = [firstbuffer, lastbuffer]
+
+            if not inparse(args):
+                return "Invalid Input!"
+            if not inparse.getparams():
+                return "\nNo Data Was Modeled!"
+
+            inparse.userinput = [int(val) for val in inparse.userinput]
+            firstbuffer, lastbuffer= inparse.userinput
+
+        xr = data.plot_limits.x_range.get()
+        yr = data.plot_limits.y_range.get()
+        zr = data.plot_limits.z_range.get()
+        br = data.plot_limits.buffer_range.get()
+        ma = data.plot_limits.is_active
+
+        commander = commands.Command()
+        pti = 1 if not xr else min(xr)
+        ptf = data.matrix.buffer(1).data.x.length() if not xr else max(xr)
+        commander(f'pl off')
+        commander(f'pl {firstbuffer} {lastbuffer} {pti} {ptf}')
+        commander(f'pl on')
+        commander(f'fit')
+        commander(f'pl off')
+
+        data.plot_limits.x_range.set(xr)
+        data.plot_limits.y_range.set(yr)
+        data.plot_limits.z_range.set(zr)
+        data.plot_limits.buffer_range.set(br)
+        data.plot_limits.is_active = ma
+        return '\nData Successfully Modeled!'
+
+
     def do_ori(self, *args):
         """\nCommand: ORIgin\n
         Description:
